@@ -4,12 +4,14 @@ from typing import Union
 
 import numpy as np
 from numpy.typing import NDArray
+from pydantic import validate_arguments
 
 from ramanchada2.misc.spectrum_deco import add_spectrum_filter
 from ..spectrum import Spectrum
 
 
 @add_spectrum_filter
+@validate_arguments(config=dict(arbitrary_types_allowed=True))
 def __truediv__(
         old_spe: Spectrum,
         new_spe: Spectrum,
